@@ -75,7 +75,6 @@ extern crate quickcheck;
 
 extern crate unicode_segmentation;
 
-use core::slice;
 use core::str;
 use unicode_segmentation::UnicodeSegmentation;
 
@@ -111,7 +110,7 @@ pub fn reverse_grapheme_clusters_in_place(s: &mut str) {
             let (grapheme, new_tail) = {tail}.split_at_mut(len);
             tail = new_tail;
             unsafe {
-                mut_bytes(grapheme).reverse();
+                grapheme.as_bytes_mut().reverse();
             }
         }
     }
@@ -119,20 +118,13 @@ pub fn reverse_grapheme_clusters_in_place(s: &mut str) {
     // Part 2: Reverse all the bytes.
     // This un-reverses all of the reversals from Part 1.
     unsafe {
-        mut_bytes(s).reverse();
+        s.as_bytes_mut().reverse();
     }
 
     // Each UTF-8 sequence is now in the right order.
     debug_assert!(str::from_utf8(s.as_bytes()).is_ok());
 }
 
-/// Convert a mutable string slice to a mutable `[u8]` slice.
-///
-/// This is unsafe if the original `str` becomes accessible while the bytes are not valid UTF-8.
-unsafe fn mut_bytes(s: &mut str) -> &mut [u8] {
-    slice::from_raw_parts_mut(s.as_ptr() as *mut u8, s.len())
-}
-
 #[cfg(test)]
 mod tests {
     use super::reverse_grapheme_clusters_in_place;
